2025/04/10 Version 2.0.1
------------------------
- `gaktest` now calls `pytest` in a subprocess
  - See [#7](https://github.com/jfhbrook/public/issues/7)

2025/04/07 Version 2.0.0
------------------------
- Renamed `gak` to `pytest_gak`
- Moved `gaktest` to separate package
- Simplified prompts
- Removed mkdocs and tox from development dependencies

2025/03/29 Version 1.0.0
------------------------
- Refactored the `plusdeck` interactive test suite into a Pytest plugin
